#ifndef _KEYSTATE_KEY_PURGE_CMD_H_
#define _KEYSTATE_KEY_PURGE_CMD_H_

extern struct cmd_func_block key_purge_funcblock;

#endif /* _KEYSTATE_KEY_PURGE_CMD_H_ */


